Crate solana_rent_collector

👎Deprecated since 2.3.0: Use Rent directly, or solana_runtime::rent_collector
Calculate and collect rent from accounts.

Structs

CollectedInfoDeprecated
Information computed during rent collection
RentCollectorDeprecated

Constants

RENT_EXEMPT_RENT_EPOCHDeprecated
When rent is collected from an exempt account, rent_epoch is set to this value. The idea is to have a fixed, consistent value for rent_epoch for all accounts that do not collect rent. This enables us to get rid of the field completely.